// Load the dataset
const csvUrl =
  'https://gist.githubusercontent.com/Praveen-Banoth/75f286859449c45c0adb4402dca2ee95/raw/8bccedada91b04fac5ae9c85dd71c2af5d9c88b3/gistfile1.txt';

// Load the dataset and create the scatter plot
d3.csv(csvUrl, d3.autoType)
  .then((data) => {
    createScatterPlot(data, 'scatter-plot');
  })
  .catch((error) => {
    console.error('Error loading the data:', error);
  });

// Function to create a scatter plot
function createScatterPlot(data, containerId) {
  const width = 800;
  const height = 500;
  const margin = {
    top: 50,
    right: 50,
    bottom: 50,
    left: 50,
  };

  // Create SVG element
  const svg = d3
    .select(`#${containerId}`)
    .append('svg')
    .attr('width', width)
    .attr('height', height);

  // Define scales for x and y axes
  const xScale = d3
    .scaleLinear()
    .domain([
      d3.min(data, (d) => d.Year),
      d3.max(data, (d) => d.Year),
    ])
    .range([margin.left, width - margin.right]);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Wins)])
    .range([height - margin.bottom, margin.top]);

  // Draw circles for each data point
  svg
    .selectAll('circle')
    .data(data)
    .enter()
    .append('circle')
    .attr('cx', (d) => xScale(d.Year))
    .attr('cy', (d) => yScale(d.Wins))
    .attr('r', 5)
    .attr('fill', 'steelblue')
    .attr('opacity', 0.7);

  // Add x-axis
  svg
    .append('g')
    .attr(
      'transform',
      `translate(0, ${height - margin.bottom})`,
    )
    .call(d3.axisBottom(xScale))
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.bottom - 10)
    .attr('fill', '#000')
    .attr('text-anchor', 'middle')
    .text('Year')
    .attr('class', 'axis-label');

  // Add y-axis
  svg
    .append('g')
    .attr('transform', `translate(${margin.left}, 0)`)
    .call(d3.axisLeft(yScale))
    .append('text')
    .attr('x', -margin.left)
    .attr('y', 10)
    .attr('fill', '#000')
    .attr('text-anchor', 'start')
    .text('Wins')
    .attr('class', 'axis-label');
}
